@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python3
 
 import cpl
 import os
@@ -31,13 +31,13 @@ a PDF file using the following URL:
 .B ftp://ftp.eso.org/pub/dfs/pipelines/{pipeline}/{pipeline}-pipeline-manual-2.9.pdf
 .PP
 An overview over the existing ESO pipelines can be found on the web page
-\\fBhttp://www.eso.org/sci/software/pipelines/\\fR.
+\\fBhttps://www.eso.org/sci/software/pipelines/\\fR.
 .PP
 Basic documentation about the EsoRex program can be found at the esorex (1) 
 man page.
 .PP
 It is possible to call the pipelines from python using the python-cpl package.
-See \\fBhttp://packages.python.org/python-cpl/index.html\\fR for further
+See \\fBhttps://packages.python.org/python-cpl/index.html\\fR for further
 information.
 .PP
 The other recipes of the {pipeline} pipeline are
@@ -109,6 +109,7 @@ for name, version in recipes:
     recipe = cpl.Recipe(name)
     f = open(os.path.join("man",
                           fname_template.format(name = name,
-                                                section=section)), "w")
+                                                section=section)), "w",
+             encoding="utf-8")
     f.write(manpage(recipe).replace('-', '\\-'))
     f.close()
